==> webkit2gtk_2.20.5.orig.tar.xz: webkitgtk-2.20.5/Tools/TestWebKitAPI/Tests/WTF/darwin/WeakLinking.cpp <==
/*
 * Copyright (C) 2017 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"

#if OS(DARWIN)

#include <sys/unistd.h>
#include <wtf/darwin/WeakLinking.h>

#if PLATFORM(IOS)

#if __IPHONE_OS_VERSION_MAX_ALLOWED >= 101000
asm(".linker_option \"-lTestWTFAlwaysMissing-iOS-v2\"");
#else
asm(".linker_option \"-lTestWTFAlwaysMissing-iOS\"");
#endif

#else

#if __MAC_OS_X_VERSION_MAX_ALLOWED >= 101200
asm(".linker_option \"-lTestWTFAlwaysMissing-macOS-v2\"");
#else
asm(".linker_option \"-lTestWTFAlwaysMissing-macOS\"");
#endif

#endif

extern "C" {
    extern void TestWTFAlwaysMissing(void) __attribute__((weak_import));
}

namespace TestWebKitAPI {

TEST(WeakLinking, IsNullFunctionPointer)
{
    EXPECT_TRUE(isNullFunctionPointer(TestWTFAlwaysMissing));
    EXPECT_FALSE(isNullFunctionPointer(close));
}

}

#endif

==> webkit2gtk_2.40.1.orig.tar.xz: webkitgtk-2.40.1/Tools/TestWebKitAPI/Tests/WTF/darwin/WeakLinking.cpp <==
/*
 * Copyright (C) 2017 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"

#if OS(DARWIN)

#include <sys/unistd.h>
#include <wtf/darwin/WeakLinking.h>

#if PLATFORM(IOS_FAMILY)

asm(".linker_option \"-lTestWTFAlwaysMissing-iOS-v2\"");

#else

asm(".linker_option \"-lTestWTFAlwaysMissing-macOS-v2\"");

#endif

extern "C" {
    extern void TestWTFAlwaysMissing(void) __attribute__((weak_import));
    extern void TestWTFAlwaysMissingWithoutAttributeWeakImport(void);
}

WTF_WEAK_LINK_FORCE_IMPORT(TestWTFAlwaysMissingWithoutAttributeWeakImport);
WTF_WEAK_LINK_FORCE_IMPORT(close);

namespace TestWebKitAPI {

TEST(WeakLinking, WeakImport)
{
    EXPECT_FALSE(TestWTFAlwaysMissing);
    EXPECT_FALSE(TestWTFAlwaysMissingWithoutAttributeWeakImport);
    EXPECT_TRUE(close);
}

}

#endif
